from setuptools import setup, find_packages


setup(
    name='calcman',
    version='0.0.1',
    description='This is a Python Package which will help you to calculate two numbers easily with only 2 lines of code!',
    author='Arinjoy Nath',
    author_email='arinjoy762@gmail.com',
    url='',
    packages=[],
)
